@@ -1,6 +1,11 @@
+try:
+    from collections.abc import Sequence
+except ImportError:
+    from collections import Sequence
 import os
 
 from importlib import import_module
+import six
 
 from statici18n.conf import settings
 
@@ -28,6 +33,21 @@ def get_filename(*args, **kwargs):
     return _filename_func(*args, **kwargs)
 
 
-def default_filename(locale, domain, output_format='js'):
+def default_filename(language_code, domain, output_format='js'):
+    return os.path.join(language_code, '%s.%s' % (domain, output_format))
+
+
+def legacy_filename(locale, domain, output_format='js'):
     from django.utils.translation.trans_real import to_language
     return os.path.join(to_language(locale), '%s.%s' % (domain, output_format))
+
+
+def get_packages(packages):
+    if packages == 'django.conf':
+        return None
+
+    if isinstance(packages, six.string_types):
+        return packages
+
+    if isinstance(packages, Sequence):
+        return '+'.join(packages)
